@@ -2,18 +2,18 @@
 #'
 #' @description Merges two genomes annotation files (GFF) into one
 #' single GFF format file saved to the desired directory. This function adds a
-#' unique prefix to the chromosome names in each genome annotation to ensure 
+#' unique prefix to the chromosome names in each genome annotation to ensure
 #' each is distinguishable within the merged file.
 #'
 #' @details
-#' As default, the function removes periods and adds a prefix to the existing 
-#' chromosome names. The prefix is separated from the original chromosome name 
-#' by an underscore. For example, based on the default settings, it will add the 
-#' prefix "A_" to the chromosome names in `annotationA`, for instance, 
-#'  A_0, A_1, A_2 etc. 
-#'  
+#' As default, the function removes periods and adds a prefix to the existing
+#' chromosome names. The prefix is separated from the original chromosome name
+#' by an underscore. For example, based on the default settings, it will add the
+#' prefix "A_" to the chromosome names in `annotationA`, for instance,
+#'  A_0, A_1, A_2 etc.
+#'
 #' The merged genome is saved to the specified output directory, and requires
-#' the user to set the name with a GFF format. 
+#' the user to set the name with a GFF format.
 #'
 #'
 #'
@@ -23,47 +23,47 @@
 #'genome,that you treat the input annotations in the same way.
 #'
 #'@return
-#'A GFF format file containing the annotations of two genomes distinguishable by 
-#'the appended prefixes. 
+#'A GFF format file containing the annotations of two genomes distinguishable by
+#'the appended prefixes.
 #'
 #'
 #'@param annotationA path; path to a genome annotation assembly file in GFF format.
 #'
 #'@param annotationB path; path to a genome annotation assembly file in GFF format.
 #'
-#'@param output_file path; a character string or a \code{base::connections()} 
+#'@param output_file path; a character string or a \code{base::connections()}
 #'open for writing. Including file output name, and must have a GFF file
-#'extension. 
+#'extension.
 #'
-#'@param AnnoA.ID character; string to represent prefix added to 
+#'@param AnnoA.ID character; string to represent prefix added to
 #'existing chromosome names in `annotationA`. Default set as "A".
 #'
-#'@param AnnoB.ID character; string to represent prefix added to 
+#'@param AnnoB.ID character; string to represent prefix added to
 #'existing chromosome names in `annotationB`. Default set as "B".
-#' 
+#'
 #'@param format format of GFF output, either "gff", "gff1", "gff2", "gff3."
-#'  Default is "gff3".  
+#'  Default is "gff3".
 #'
 #'
 #' @examples
-#' 
-#' anno1 <- system.file("extdata", "reduced_chr12_Eggplant.gff.gz", 
+#'
+#' anno1 <- system.file("extdata", "reduced_chr12_Eggplant.gff.gz",
 #' package="mobileRNA")
-#' 
+#'
 #' anno2 <- system.file("extdata","reduced_chr2_Tomato.gff.gz",
 #' package="mobileRNA")
-#' 
+#'
 #' output_file <- tempfile("merged_annotation", fileext = ".gff3")
-#' 
+#'
 #' merged_anno <- RNAmergeAnnotations(annotationA = anno1, annotationB = anno2,
 #'                                    output_file = output_file)
-#'                                    
+#'
 #' @importFrom rtracklayer import
 #' @importFrom rtracklayer export
 #' @importFrom GenomicRanges GRangesList
 #' @importFrom progress progress_bar
-#' @importFrom S4Vectors elementMetadata 
-#' @importFrom Seqinfo seqlevels
+#' @importFrom S4Vectors elementMetadata
+#' @importFrom GenomeInfoDb seqlevels
 #' @export
 #'
 RNAmergeAnnotations <- function(annotationA, annotationB,
@@ -80,10 +80,10 @@ RNAmergeAnnotations <- function(annotationA, annotationB,
       !file.exists(annotationB)){
     stop("Please specify annotationA; path to GFF file.")
   }
-  if (base::missing(output_file) || 
+  if (base::missing(output_file) ||
       !grepl("\\.(gff)$|\\.(gff1)$|\\.(gff2)$|\\.(gff3)$|\\.(gff.gz)$|
              \\.(gff1.gz)$|\\.(gff2.gz)$|\\.(gff3.gz)$",output_file)) {
-    stop("Please specify output_file, a connection to a local directory to write 
+    stop("Please specify output_file, a connection to a local directory to write
           and save merged annotation.
           Ensure file contains suitable GFF extension.")
   }
@@ -91,33 +91,33 @@ RNAmergeAnnotations <- function(annotationA, annotationB,
   pb <- progress::progress_bar$new(
     format = "[:bar] :percent :current/:total :eta",
     total = 4)
-  pb$tick(0)  
-  
+  pb$tick(0)
+
   # import gff
   annotationA <- rtracklayer::import(annotationA)
-  annotationB <- rtracklayer::import(annotationB) 
+  annotationB <- rtracklayer::import(annotationB)
   pb$tick()
-  
+
   # remove full-stop
-  annotationA_seqnames <- gsub("\\.", "", paste0(AnnoA.ID, "_",   
-                                          Seqinfo::seqlevels(annotationA)))
+  annotationA_seqnames <- gsub("\\.", "", paste0(AnnoA.ID, "_",
+                                                 GenomeInfoDb::seqlevels(annotationA)))
   annotationB_seqnames <- gsub("\\.", "", paste0(AnnoB.ID, "_",
-                                         Seqinfo::seqlevels(annotationB)))
-  
+                                                 GenomeInfoDb::seqlevels(annotationB)))
+
   # change seqnames
-  Seqinfo::seqlevels(annotationA) <- annotationA_seqnames
-  Seqinfo::seqlevels(annotationB) <- annotationB_seqnames
+  GenomeInfoDb::seqlevels(annotationA) <- annotationA_seqnames
+  GenomeInfoDb::seqlevels(annotationB) <- annotationB_seqnames
 
   pb$tick()
- # change classes 
+ # change classes
   annotationA_gff <- convertChar2Factor(annotationA)
   annotationB_gff <- convertChar2Factor(annotationB)
 
   pb$tick()
-  # join 
+  # join
   gr_list <- GenomicRanges::GRangesList(annotationA_gff, annotationB_gff)
   concatenated_gff <- unlist(gr_list)
-  # export merged 
+  # export merged
   rtracklayer::export(concatenated_gff, output_file, format=format)
   pb$tick()
   message("\nOutput file has been saved to: ", output_file)
