@@ -16,14 +16,14 @@ cap01<-"Comprehensive diagram of complete mobileRNA workflows. "
 knitr::include_graphics("../man/figures/mobileRNA_graphic_2.png")
 
 ## ----eval=FALSE, message=FALSE------------------------------------------------
-#  if (!require("BiocManager", quietly = TRUE))
-#      install.packages("BiocManager")
-#  
-#  BiocManager::install("mobileRNA")
+# if (!require("BiocManager", quietly = TRUE))
+#     install.packages("BiocManager")
+# 
+# BiocManager::install("mobileRNA")
 
 ## ----eval=FALSE, message=FALSE------------------------------------------------
-#  if (!require("devtools")) install.packages("devtools")
-#  devtools::install_github("KJeynesCupper/mobileRNA", ref = "main")
+# if (!require("devtools")) install.packages("devtools")
+# devtools::install_github("KJeynesCupper/mobileRNA", ref = "main")
 
 ## ----message=FALSE------------------------------------------------------------
 library("mobileRNA")
@@ -67,32 +67,32 @@ merged_annotation <- RNAmergeAnnotations(annotationA = anno1,
                                          output_file = output_annotation_file)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  # directory containing only sRNAseq samples
-#  samples <- system.file("extdata/sRNAseq",package="mobileRNA")
-#  
-#  # output location
-#  output_location <- tempdir()
-#  
-#  mapRNA(input = "sRNA",
-#         input_files_dir = samples,
-#         output_dir = output_location,
-#         genomefile = output_assembly_file,
-#         condaenv = "/Users/user-name/miniconda3/envs/ShortStack4",
-#         mmap = "n")
+# # directory containing only sRNAseq samples
+# samples <- system.file("extdata/sRNAseq",package="mobileRNA")
+# 
+# # output location
+# output_location <- tempdir()
+# 
+# mapRNA(input = "sRNA",
+#        input_files_dir = samples,
+#        output_dir = output_location,
+#        genomefile = output_assembly_file,
+#        condaenv = "/Users/user-name/miniconda3/envs/ShortStack4",
+#        mmap = "n")
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  # Directory containing results
-#  results_dir <-  file.path(output_location,"2_sRNA_results")
-#  
-#  # Sample names and total number of reads, in the same order.
-#  sample_names <- c("selfgraft_demo_1", "selfgraft_demo_2",
-#                    "selfgraft_demo_3", "heterograft_demo_1",
-#                    "heterograft_demo_2", "heterograft_demo_3")
-#  
-#  
-#  sRNA_data_demo <- RNAimport(input = "sRNA",
-#                              directory = results_dir,
-#                              samples = sample_names)
+# # Directory containing results
+# results_dir <-  file.path(output_location,"2_sRNA_results")
+# 
+# # Sample names and total number of reads, in the same order.
+# sample_names <- c("selfgraft_demo_1", "selfgraft_demo_2",
+#                   "selfgraft_demo_3", "heterograft_demo_1",
+#                   "heterograft_demo_2", "heterograft_demo_3")
+# 
+# 
+# sRNA_data_demo <- RNAimport(input = "sRNA",
+#                             directory = results_dir,
+#                             samples = sample_names)
 
 ## -----------------------------------------------------------------------------
 data("sRNA_data")
@@ -108,8 +108,8 @@ mobile_sRNA <- RNAmobile(input = "sRNA",
                          task = "keep")
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  # save output as txt file
-#  write.table(mobile_sRNA, "./sRNA_mobile_output.txt")
+# # save output as txt file
+# write.table(mobile_sRNA, "./sRNA_mobile_output.txt")
 
 ## ----echo=FALSE---------------------------------------------------------------
 cap1 <- "An example facet line graph to show the distribution of sRNA classes within each sample."
@@ -205,7 +205,7 @@ RNAsummary(sRNA_DESeq2, alpha=0.05)
 
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  write.table(sRNA_DESeq2, "./sRNA_core_dataset.txt")
+# write.table(sRNA_DESeq2, "./sRNA_core_dataset.txt")
 
 ## ----fig.show="hold"----------------------------------------------------------
 # summary of statistical sRNA clusters
@@ -284,17 +284,19 @@ p2 <- plotHeatmap(mobile_sRNA, row.names = FALSE)
 p2$plot
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  write.table(mobile_sRNA, "./candidate_mobile_sRNAs.txt")
+# write.table(mobile_sRNA, "./candidate_mobile_sRNAs.txt")
 
 ## -----------------------------------------------------------------------------
-annotation_file <- system.file("extdata", 
-                                    "prefix_reduced_chr2_Tomato.gff.gz",
-                                    package="mobileRNA")
+annotation_file <- system.file("extdata",
+                     "prefix_reduced_chr2_Tomato.gff", 
+                     package="mobileRNA")
 
 mobile_attributes <- RNAattributes(data = mobile_sRNA, 
                                       match ="genes",
                                       annotation = annotation_file)
 
+
+
 ## -----------------------------------------------------------------------------
 mobile_features <- RNAfeatures(data = mobile_sRNA, 
                                annotation = annotation_file)
@@ -310,7 +312,7 @@ plot(features_plot)
 mobile_sequences <- RNAsequences(mobile_sRNA, method = "consensus") 
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  write.table(mobile_sequences, "./candidate_mobile_sRNA_sequences.txt")
+# write.table(mobile_sequences, "./candidate_mobile_sRNA_sequences.txt")
 
 ## ----message=FALSE------------------------------------------------------------
 # load `dplyr` package
@@ -329,98 +331,98 @@ res <- do.call(rbind, lapply(seq(nrow(sequences)),
                              function(i) t(sequences[i, ])))
 
 ## ----eval = FALSE, message=FALSE----------------------------------------------
-#  # save output
-#  write.table(res, file ="./mobile_sRNA_sequences.txt",
-#              row.names = FALSE, col.names = FALSE, quote = FALSE)
+# # save output
+# write.table(res, file ="./mobile_sRNA_sequences.txt",
+#             row.names = FALSE, col.names = FALSE, quote = FALSE)
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  # load `bioseq` package
-#  library(bioseq)
-#  
-#  # build a RNA vector from a character vector:
-#  mobileRNA_seq <- bioseq::rna(mobile_sequences$Sequence)
-#  
-#  # Find a consensus sequence for a set of sequences:
-#  bioseq::seq_consensus(mobileRNA_seq)
+# # load `bioseq` package
+# library(bioseq)
+# 
+# # build a RNA vector from a character vector:
+# mobileRNA_seq <- bioseq::rna(mobile_sequences$Sequence)
+# 
+# # Find a consensus sequence for a set of sequences:
+# bioseq::seq_consensus(mobileRNA_seq)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  # names of samples, represented by folder names produced in previous step
-#  samples <- c("[sample names]")
-#  
-#  # location of output folders from previous step
-#  dir <- "[output_dir]"
-#  
-#  # merge information of the detected de novo sRNA clusters
-#  gff_alignment <- GenomicRanges::GRangesList()
-#  for (i in samples) {
-#    file_path <- file.path(dir, i, "Results.gff.gz3")
-#    if (file.exists(file_path)) {
-#      gff_alignment[[i]] <- rtracklayer::import.gff.gz(file_path)
-#    } else{
-#      Stop("File does not exist:", file_path, "\n")
-#    }
-#  }
-#  
-#  gff_merged <- GenomicRanges::reduce(unlist(gff_alignment),
-#                                      ignore.strand = TRUE)
-#  
-#  gff_merged <- as.data.frame(gff_merged)
-#  colnames(gff_merged)[1] <- "chr"
-#  if('*' %in% gff_merged$strand){
-#      gff_merged <- gff_merged[, -match("strand", colnames(gff_merged))]
-#    }
-#  
-#  locifile_txt <- data.frame(Locus = paste0(gff_merged$chr, ":",
-#                                            gff_merged$start,"-",
-#                                            gff_merged$end),
-#                             Cluster = paste0("cluster_",
-#                                              seq_len(nrow(gff_merged))))
-#  
-#  # save output to location
-#  dir_locifile <- "[output directory]"
-#  loci_out <- file.path(dir_locifile,"locifile.txt")
-#  utils::write.table(locifile_txt, file = loci_out, quote = FALSE,
-#                     sep = "\t", row.names = FALSE, col.names = TRUE)
-#  
+# # names of samples, represented by folder names produced in previous step
+# samples <- c("[sample names]")
+# 
+# # location of output folders from previous step
+# dir <- "[output_dir]"
+# 
+# # merge information of the detected de novo sRNA clusters
+# gff_alignment <- GenomicRanges::GRangesList()
+# for (i in samples) {
+#   file_path <- file.path(dir, i, "Results.gff.gz3")
+#   if (file.exists(file_path)) {
+#     gff_alignment[[i]] <- rtracklayer::import.gff(file_path)
+#   } else{
+#     Stop("File does not exist:", file_path, "\n")
+#   }
+# }
+# 
+# gff_merged <- GenomicRanges::reduce(unlist(gff_alignment),
+#                                     ignore.strand = TRUE)
+# 
+# gff_merged <- as.data.frame(gff_merged)
+# colnames(gff_merged)[1] <- "chr"
+# if('*' %in% gff_merged$strand){
+#     gff_merged <- gff_merged[, -match("strand", colnames(gff_merged))]
+#   }
+# 
+# locifile_txt <- data.frame(Locus = paste0(gff_merged$chr, ":",
+#                                           gff_merged$start,"-",
+#                                           gff_merged$end),
+#                            Cluster = paste0("cluster_",
+#                                             seq_len(nrow(gff_merged))))
+# 
+# # save output to location
+# dir_locifile <- "[output directory]"
+# loci_out <- file.path(dir_locifile,"locifile.txt")
+# utils::write.table(locifile_txt, file = loci_out, quote = FALSE,
+#                    sep = "\t", row.names = FALSE, col.names = TRUE)
+# 
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  # names of samples, represented by folder names produced in previous step
-#  samples <- c("[sample names]")
-#  
-#  # location of output folders from previous step
-#  dir <- "[output_dir]"
-#  
-#  # merge information of the detected de novo sRNA clusters
-#  gff_alignment <- GenomicRanges::GRangesList()
-#  for (i in samples) {
-#    file_path <- file.path(dir, i, "Results.gff.gz3")
-#    if (file.exists(file_path)) {
-#      gff_alignment[[i]] <- rtracklayer::import.gff.gz(file_path)
-#    } else{
-#      Stop("File does not exist:", file_path, "\n")
-#    }
-#  }
-#  
-#  gff_merged <- GenomicRanges::reduce(unlist(gff_alignment),
-#                                      ignore.strand = TRUE)
-#  
-#  gff_merged <- as.data.frame(gff_merged)
-#  colnames(gff_merged)[1] <- "chr"
-#  if('*' %in% gff_merged$strand){
-#      gff_merged <- gff_merged[, -match("strand", colnames(gff_merged))]
-#    }
-#  
-#  locifile_txt <- data.frame(Locus = paste0(gff_merged$chr, ":",
-#                                            gff_merged$start,"-",
-#                                            gff_merged$end),
-#                             Cluster = paste0("cluster_",
-#                                              seq_len(nrow(gff_merged))))
-#  
-#  # save output to location
-#  dir_locifile <- "[output directory]"
-#  loci_out <- file.path(dir_locifile,"locifile.txt")
-#  utils::write.table(locifile_txt, file = loci_out, quote = FALSE,
-#                     sep = "\t", row.names = FALSE, col.names = TRUE)
+# # names of samples, represented by folder names produced in previous step
+# samples <- c("[sample names]")
+# 
+# # location of output folders from previous step
+# dir <- "[output_dir]"
+# 
+# # merge information of the detected de novo sRNA clusters
+# gff_alignment <- GenomicRanges::GRangesList()
+# for (i in samples) {
+#   file_path <- file.path(dir, i, "Results.gff.gz3")
+#   if (file.exists(file_path)) {
+#     gff_alignment[[i]] <- rtracklayer::import.gff(file_path)
+#   } else{
+#     Stop("File does not exist:", file_path, "\n")
+#   }
+# }
+# 
+# gff_merged <- GenomicRanges::reduce(unlist(gff_alignment),
+#                                     ignore.strand = TRUE)
+# 
+# gff_merged <- as.data.frame(gff_merged)
+# colnames(gff_merged)[1] <- "chr"
+# if('*' %in% gff_merged$strand){
+#     gff_merged <- gff_merged[, -match("strand", colnames(gff_merged))]
+#   }
+# 
+# locifile_txt <- data.frame(Locus = paste0(gff_merged$chr, ":",
+#                                           gff_merged$start,"-",
+#                                           gff_merged$end),
+#                            Cluster = paste0("cluster_",
+#                                             seq_len(nrow(gff_merged))))
+# 
+# # save output to location
+# dir_locifile <- "[output directory]"
+# loci_out <- file.path(dir_locifile,"locifile.txt")
+# utils::write.table(locifile_txt, file = loci_out, quote = FALSE,
+#                    sep = "\t", row.names = FALSE, col.names = TRUE)
 
 ## -----------------------------------------------------------------------------
 sessionInfo()
